@@ -2,7 +2,13 @@ from .. import Provider as AutomotiveProvider
 
 
 class Provider(AutomotiveProvider):
-    # Source (english): https://en.wikipedia.org/wiki/Vehicle_registration_plates_of_France
+    """Implement automotive provider for ``fr_FR`` locale.
+
+    Sources:
+
+    - https://en.wikipedia.org/wiki/Vehicle_registration_plates_of_France
+    """
+
     license_formats = (
         # New format
         '??-###-??',
